@@ -26,10 +26,13 @@
 #include "devicemanager.h"
 #include <KIO/Global>
 #include <KIO/CopyJob>
+#include <KIO/MkpathJob>
 #include <KIO/FileUndoManager>
 #include <KIO/JobUiDelegate>
 #include <KFormat>
+#include <KFileUtils>
 #include <KJobWidgets/KJobWidgets>
+#include <KLocalizedString>
 #include <QFile>
 #include <QJsonArray>
 #include <QDir>
@@ -57,7 +60,7 @@ QUrl Kamoso::fileNameSuggestion(const QUrl &saveUrl, const QString &name, const
     QUrl url(saveUrl.toString() + '/' + initialName);
 
     if (url.isLocalFile() && QFile::exists(url.toLocalFile())) {
-        url.setPath(saveUrl.path() + '/' + KIO::suggestName(saveUrl, initialName));
+        url.setPath(saveUrl.path() + '/' + KFileUtils::suggestName(saveUrl, initialName));
     }
 
     return url;
@@ -97,11 +100,31 @@ void Kamoso::setRecording(bool recording)
         m_webcamControl->startRecording();
         m_recordingTime.restart();
         m_recordingTimer.start();
+        auto job = KIO::mkpath(Settings::saveVideos());
+        job->start();
+        connect(job, &KJob::finished, this, [this, job] {
+            if (job->error() == 0) {
+                return;
+            }
+
+            qWarning() << "Could not create" << Settings::saveVideos();
+            Q_EMIT error(job->errorString());
+        });
     } else {
         const QUrl path = fileNameSuggestion(Settings::saveVideos(), "video", "mkv");
 
-        KJob *job = KIO::move(QUrl::fromLocalFile(m_webcamControl->stopRecording()), path);
+        const auto temp = m_webcamControl->stopRecording();
+        KJob *job = KIO::move(QUrl::fromLocalFile(temp), path);
         job->start();
+        connect(job, &KJob::finished, this, [this, temp, path, job] {
+            if (job->error() == 0) {
+                qDebug() << "video saved successfully";
+                return;
+            }
+
+            qWarning() << "Could not move" << temp << "to" << path;
+            Q_EMIT error(job->errorString());
+        });
 
         m_webcamControl->playDevice(DeviceManager::self()->playingDevice());
         m_recordingTimer.stop();
